=======
History
=======

0.1.1 (2023-06-10)
------------------

* Fix relative output directory bug.
* Fix incorrect file parsing bug.
* Fix double path error reporting bug.

0.1.0 (2023-06-09)
------------------

* Release working version.

0.0.1 (2023-06-09)
------------------

* First release on PyPI.
